/*****************************************************************************
 *   rtc.h:  Header file for Philips LPC214x Family Microprocessors
 *
 *   Copyright(C) 2006, Philips Semiconductor
 *   All rights reserved.
 *
 *   History
 *   2005.10.01  ver 1.00    Prelimnary version, first Release
 *
******************************************************************************/

/*
	modified by Martin Thomas
	- Prescalers calculated by preprocessor for pclk defined in target.h
	- configuration-option for 32kHz XTAL
	- "global" second_tick to demonstrate counter-intrement-int
*/

#ifndef INC_TIMER_H
#define INC_TIMER_H

#include "types.h"
#include "LPC21xx.h"
#include "config.h"

//#define T1PRESCALER    (0x01C9C380 >> 1) //1Sec
//#define T1PRESCALER    (0x7530 >> 1) //1mSec
#define T1PRESCALER    (0x000493E0 >> 1) //10mSec
//
#define RTC_INT_MODE
// define the following to use the 32kHz XTAL for the RTC
////#define RTC_USE_32KHZ

//#ifdef RTC_USE_32KHZ
//#warning "Using 32kHz XTAL as RTC clock-source"
//#else
//#warning "Using PCLK as RTC clock-source"
//#endif

typedef struct
{
    uint32_t RTC_Sec;     /* Second value - [0,59] */
    uint32_t RTC_Min;     /* Minute value - [0,59] */
    uint32_t RTC_Hour;    /* Hour value - [0,23] */
    uint32_t RTC_Mday;    /* Day of the month value - [1,31] */
    uint32_t RTC_Mon;     /* Month value - [1,12] */
    uint32_t RTC_Year;    /* Year value - [0,4095] */
    uint32_t RTC_Wday;    /* Day of week value - [0,6] */
    uint32_t RTC_Yday;    /* Day of year value - [1,365] */
} RTCTime;

//static char *RTC_WdayLUT[] = {
//	"Sunday ",
//	"Monday ",
//	"Tuesday ",
//	"Wednesday ",
//	"Thursday ",
//	"Friday ",
//	"Saturday "
//};
//
//static char *RTC_MonLUT[] = {
//	"",
//	"January ",
//	"February ",
//	"Match ",
//	"April ",
//	"May ",
//	"June ",
//	"July ",
//	"August ",
//	"September ",
//	"October ",
//	"November ",
//	"December "
//};

#define IMSEC		0x00000001
#define IMMIN		0x00000002
#define IMHOUR		0x00000004
#define IMDOM		0x00000008
#define IMDOW		0x00000010
#define IMDOY		0x00000020
#define IMMON		0x00000040
#define IMYEAR		0x00000080

#define AMRSEC		0x00000001  /* Alarm mask for Seconds */
#define AMRMIN		0x00000002  /* Alarm mask for Minutes */
#define AMRHOUR		0x00000004  /* Alarm mask for Hours */
#define AMRDOM		0x00000008  /* Alarm mask for Day of Month */
#define AMRDOW		0x00000010  /* Alarm mask for Day of Week */
#define AMRDOY		0x00000020  /* Alarm mask for Day of Year */
#define AMRMON		0x00000040  /* Alarm mask for Month */
#define AMRYEAR		0x00000080  /* Alarm mask for Year */

#define PREINT_RTC  ((PCLK/32768)-1)
#define PREFRAC_RTC (PCLK-((PREINT_RTC+1)*32768))
////#if 1

///////* mthomas: let the preprocessor do the calculations */
//////#include "target.h"
//////#define PREINT_RTC  ((PCLK/32768)-1)
//////#define PREFRAC_RTC (PCLK-((PREINT_RTC+1)*32768))
//////#else
///////* hardcoded values from the original code */
//////#define PREINT_RTC	0x000001C8  /* Prescaler value, integer portion,
//////PCLK = 15Mhz */
//////#define PREFRAC_RTC	0x000061C0  /* Prescaler value, fraction portion,
//////PCLK = 15Mhz */
//////#endif


#define ILR_RTCCIF	0x01
#define ILR_RTCALF	0x02

#define CCR_CLKEN	0x01
#define CCR_CTCRST	0x02
#define CCR_CLKSRC	(1UL<<4) /*0x10*/

// extern void RTCHandler (void) __irq;
// extern void RTCInit( void );
// extern void RTCStart( void );
// extern void RTCStop( void );
// extern void RTC_CTCReset( void );
// extern void RTCSetTime( RTCTime );
// extern RTCTime RTCGetTime( void );
// extern void RTCSetAlarm( RTCTime );
// extern void RTCSetAlarmMask( uint32_t AlarmMask );

// extern volatile uint32_t alarm_on;
// extern volatile uint32_t second_tick;

//extern volatile uint32_t alarm_on;
//extern volatile uint32_t second_tick;
/*****************************************************************************
** Function name:		cfgTimer1
**
** Descriptions:		Initialize Timer1
**
** parameters:			None
** Returned value:		None
**
*****************************************************************************/
void cfgTimer1(void);
/*****************************************************************************
** Function name:		RTCInit
**
** Descriptions:		Initialize RTC timer
**
** parameters:			None
** Returned value:		None
**
*****************************************************************************/
void cfgRTC( void );
/*****************************************************************************
** Function name:		RTCStart
**
** Descriptions:		Start RTC timer
**
** parameters:			None
** Returned value:		None
**
*****************************************************************************/
void RTCStart( void );
/*****************************************************************************
** Function name:		RTCStop
**
** Descriptions:		Stop RTC timer
**
** parameters:			None
** Returned value:		None
**
*****************************************************************************/
void RTCStop( void );
/*****************************************************************************
** Function name:		RTC_CTCReset
**
** Descriptions:		Reset RTC clock tick counter
**
** parameters:			None
** Returned value:		None
**
*****************************************************************************/
void RTC_CTCReset( void );
/*****************************************************************************
** Function name:		RTCSetTime
**
** Descriptions:		Setup RTC timer value
**
** parameters:			None
** Returned value:		None
**
*****************************************************************************/
void RTCSetTime( RTCTime Time );
/*****************************************************************************
** Function name:		RTCSetAlarm
**
** Descriptions:		Initialize RTC timer
**
** parameters:			None
** Returned value:		None
**
*****************************************************************************/
void RTCSetAlarm( RTCTime Alarm );
/*****************************************************************************
** Function name:		RTCGetTime
**
** Descriptions:		Get RTC timer value
**
** parameters:			None
** Returned value:		The data structure of the RTC time table
**
*****************************************************************************/
RTCTime RTCGetTime( void );
/*****************************************************************************
** Function name:		RTCSetAlarmMask
**
** Descriptions:		Set RTC timer alarm mask
**
** parameters:			Alarm mask setting
** Returned value:		None
**
*****************************************************************************/
void RTCSetAlarmMask( uint32_t AlarmMask );
/*****************************************************************************
**                            End Of File
******************************************************************************/
#endif /* end __RTC_H */

