/******************************************************************************
 *
 * WinARM Demo-Application
 * by Martin THOMAS <eversmith@heizung-thomas.de>
 * based on code from Bill Knight, R O SoftWare <BillK@rosw.com>
 *
 * - UART0 and UART1 send and receive (also in Interrupt-Mode)
 * - Sends message if button "INT1" (P0.14) on demo-board have been hit.
 * - LED blink (2 of the 8 LEDs on the MCB2130)
 * - Thumb/Interwork (makefile)
 * - Adapted to the Keil MCB2130 demo-board (Philips LPC2138) (config.h)
 *
 *
 * $RCSfile: $
 * $Revision: $
 *
 *****************************************************************************/
#include <ctype.h>
#include <string.h>
#include <stdlib.h>
#include "types.h"
#include "LPC21xx.h"
#include "config.h"
#include "armVIC.h"
#include "sysTime.h"
#include "timer.h"
#include "uart.h"
#include "lcdt/lcd.h"
#include "myprintf.h"



#define FNAME ("myhwml.cfg")
#define NUMLENGTH 13

extern void lowInit(void);

uint32_t volatile rtcif = 0;
uint32_t volatile t1tick = 0;
uint8_t flag;
BOOL showclock;
/* prototypes */
void initLocalTime(void);

/******************************************************************************
 * Function Name: sysInit()
 *
 * Description:
 *    This function is responsible for initializing the program
 *    specific hardware
 * Returns:
 *    void
 *****************************************************************************/
static void sysInit(void)
{
  lowInit();                            // setup clocks and processor port pins
  MEMMAP = MEMMAP_FLASH;                // map interrupt vectors space into FLASH
  VICIntEnClear = 0xFFFFFFFF;           // clear all interrupts
  VICIntSelect = 0x00000000;            // clear all FIQ selections
  VICDefVectAddr = (uint32_t)reset;     // point unvectored IRQs to reset()

  //  wdtInit();                            // initialize the watchdog timer
  initSysTime();
  cfgGLCD();
  cfgRTC();
  uart0Init(UART_BAUD(HOST_BAUD), UART_8N1, UART_FIFO_8); // setup the UART
  //uart1Init(UART_BAUD(HOST_BAUD), UART_8N1, UART_FIFO_8); // setup the UART
}

/* Real Time Clock */
RTCTime local_time,  current_time;//alarm_time,

//-----------------------------------------------------------------------
// Preset Local Time
//-----------------------------------------------------------------------
void initLocalTime(void)
{
  local_time.RTC_Sec = 55;
  local_time.RTC_Min = 55;
  local_time.RTC_Hour = 23;
  local_time.RTC_Mday = 22;
  local_time.RTC_Wday = 2;
  local_time.RTC_Yday = 3;		/* "current date" 11/20/2007 00:00:55*/
  local_time.RTC_Mon = 01;
  local_time.RTC_Year = 2008;
  RTCSetTime( local_time );		/* Set local time */

}

static void boxanimate(void)
{

  uint8_t i;

  do
    {
      i = 0;
      do
        {
          gotoxy(i, i);
          box(239-4*i, 127-4*i);
          refresh_LCD(0);	//refresh for each box
//          pause(TWENTY_MS);
        }
      while (i++ < 30);
      set_display(F5x8, (flag) ? NORMAL : REVERSE);
      flag = !flag;
    }
  while (flag);

  // wait for moment please....
  pause(ONE_SEC);
  clearlcd(ALL);
  refresh_LCD(0);

  //
  // test for vertical lines drawings
  i = 0;
  do
    {
      gotoxy(i*8, 0);
      vline(127);
    }
  while (i++ < 30);

  refresh_LCD(0);    						    //refresh all frame

  //
  // test for horizontal lines drawings
  i = 0;
  do
    {
      gotoxy(0, i*8);
      hline(239);
      refresh_LCD(0);    					    // refresh for each line
    }
  while (i++ < 16);

  pause(TWO_SEC);

  clearlcd (ALL);

  // test fonts
  set_display(F5x8, NORMAL);
  gotoxy(2,10);
  wrstr("5/8 FONT");
  gotoxy(0,0);
  box(239,127);
  gotoxy(40,44);
  box(160,40);
  wrstr("ABCDEFG 160x40 box Test routine");
  refresh_LCD(0);

}
/******************************************************************************
 *
 * Function Name: main()
 *
 * Description:
 *    This function is the program entry point.  After initializing the
 *    system, it sends a greeting out UART0 then enters an endless loop
 *    echoing chracters on the UART and blinking an LED every half
 *    second.
 *
 * Calling Sequence:
 *    void
 *
 * Returns:
 *    void
 *
 *****************************************************************************/
int main(void)
{

  flag = 1;
  /* mcu initialization */
  sysInit();
  enableIRQ();
  initLocalTime();
  RTCStart();


  // test for box drawings
  boxanimate();

  pause(ONE_SEC);

  //clearlcd (ALL);



  for (;;)
    {

      int ch;
      if ((ch = uart0Getch()) >= 0)
        {
          switch (ch)
            {
            case 13:
              break;
            case 's':
              showclock ^= 1;//toggle
              break;
            case 'f':
              clearlcd (ALL);
              refresh_LCD(0);
              flag = 1;
              boxanimate();
              break;
            case 'c':
              //clearlcd();
              break;
            default:
              uart0Putch(ch);//out to uart
//              xputc(ch);//out to lcd
              break;

            }

        }
      if (showclock)
        {
          gotoxy(1,1);
          current_time = RTCGetTime();
          xprintf("%u.%u.%u %2u:%2u:%2u", current_time.RTC_Mday, current_time.RTC_Year, current_time.RTC_Mon,
                  current_time.RTC_Hour, current_time.RTC_Min, current_time.RTC_Sec);
          refresh_LCD(0);
        }
    } //!!for

  return 0; //never reach here
}//!!main!!
